==> cherry-metaplex-js-1.0.1.tgz: package/src/actions/initStoreV2.ts <==
import { PublicKey } from '@solana/web3.js';
import { Wallet } from '../wallet';
import { Connection } from '../Connection';
import { sendTransaction } from './transactions';
import { SetStoreV2, Store, StoreConfig } from '@metaplex-foundation/mpl-metaplex';
import {WalletContextState} from '@solana/wallet-adapter-react' //ksy

/** Parameters for {@link initStoreV2} **/
export interface InitStoreV2Params {
  connection: Connection;
  /** Administrator wallet for the store **/
  wallet: Wallet;
  wallets: WalletContextState; //ksy
  /**
   * - `true`: anyone can list on the store
   * - `false`: only [whitelisted creators](https://docs.metaplex.com/architecture/deep_dive/metaplex#whitelistedcreator) can list on the store
   **/
  isPublic?: boolean;
  settingsUri?: string | null;
}

export interface InitStoreV2Response {
  storeId: PublicKey;
  configId: PublicKey;
  txId: string;
}

/**
 * Initialize a {@link Store} account.
 * This action will get {@link Store} and {@link StoreConfig} program derived account addresses for the provided wallet and initialize a store, setting the given `wallet` as the admin
 */
export const initStoreV2 = async ({
  connection,
  wallet,
  wallets, //ksy
  settingsUri = null,
  isPublic = true,
}: InitStoreV2Params): Promise<InitStoreV2Response> => {
  const storeId = await Store.getPDA(wallet.publicKey);
  const configId = await StoreConfig.getPDA(storeId);
  const tx = new SetStoreV2(
    { feePayer: wallet.wallet.adapter.feePayer }, //기존 wallet.publicKey
    {
      admin: new PublicKey(wallet.publicKey),
      store: storeId,
      config: configId,
      isPublic,
      settingsUri,
    },
  );

  const txId = await sendTransaction({ connection, wallet,wallets, txs: [tx] });

  return { storeId, configId, txId };
};

==> cherry-metaplex-js-1.0.3.tgz: package/src/actions/initStoreV2.ts <==
import { PublicKey } from '@solana/web3.js';
import { Wallet } from '../wallet';
import { Connection } from '../Connection';
import { sendTransaction } from './transactions';
import { SetStoreV2, Store, StoreConfig } from '@metaplex-foundation/mpl-metaplex';
//import {WalletContextState} from '@solana/wallet-adapter-react' //ksy

/** Parameters for {@link initStoreV2} **/
export interface InitStoreV2Params {
  connection: Connection;
  /** Administrator wallet for the store **/
  wallet: Wallet;
  //wallets: WalletContextState; //ksy
  /**
   * - `true`: anyone can list on the store
   * - `false`: only [whitelisted creators](https://docs.metaplex.com/architecture/deep_dive/metaplex#whitelistedcreator) can list on the store
   **/
  isPublic?: boolean;
  settingsUri?: string | null;
}

export interface InitStoreV2Response {
  storeId: PublicKey;
  configId: PublicKey;
  txId: string;
}

/**
 * Initialize a {@link Store} account.
 * This action will get {@link Store} and {@link StoreConfig} program derived account addresses for the provided wallet and initialize a store, setting the given `wallet` as the admin
 */
export const initStoreV2 = async ({
  connection,
  wallet,
  //wallets, //ksy
  settingsUri = null,
  isPublic = true,
}: InitStoreV2Params): Promise<InitStoreV2Response> => {
  const storeId = await Store.getPDA(wallet.publicKey);
  const configId = await StoreConfig.getPDA(storeId);
  const tx = new SetStoreV2(
    { feePayer: wallet.wallet.adapter.feePayer }, //기존 wallet.publicKey
    {
      admin: new PublicKey(wallet.publicKey),
      store: storeId,
      config: configId,
      isPublic,
      settingsUri,
    },
  );

  const txId = await sendTransaction({ connection, wallet, txs: [tx] });

  return { storeId, configId, txId };
};
